@@ -1,6 +1,6 @@
 package Antispam::Toolkit::Role::BerkeleyDB;
 BEGIN {
-  $Antispam::Toolkit::Role::BerkeleyDB::VERSION = '0.04';
+  $Antispam::Toolkit::Role::BerkeleyDB::VERSION = '0.05';
 }
 
 use strict;
@@ -12,6 +12,11 @@ use Antispam::Toolkit::Types qw( Bool File NonEmptyStr DataFile );
 use BerkeleyDB;
 use DateTime;
 
+BEGIN {
+    die 'The ' . __PACKAGE__ . ' role requires a BerkeleyDB linked against Berkeley DB 4.4+'
+        unless $BerkeleyDB::db_version >= 4.4;
+}
+
 use Moose::Role;
 use MooseX::Params::Validate qw( validated_list );
 
@@ -168,7 +173,7 @@ Antispam::Toolkit::Role::BerkeleyDB - A role for classes which store spam check
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
